Fonts: Intuitive
================

Intuitive is a hand-drawn font by Bruno de Souza Leão released under the OFL.

Preview: https://fontlibrary.org/en/font/intuitive

This font has been repackaged for the Python Fonts module: https://pypi.org/project/fonts/

Copyright, Bruno de Souza Leão. Redistributed under the terms of the SIL Open Font License: https://scripts.sil.org/cms/scripts/page.php?site_id=nrsi&id=OFL
